Variance of some remotely-sensed Earth data is time-varying. Utilizing the observations per period (season, year), this function allows for estimation of variability in data either as numeric vector or matricial form
hetervar(
x,
m = NULL,
lenPeriod = 23,
method = c("standard", "robust-mad", "robust-Qn")
)A numeric vector of length lenPeriod
numeric vector
matrix with nrow equal to the number of periods (seasons
or years) analyzed and ncol equal to the number of observations
per period
numeric giving the number of observations per period. Default, 23.
character specifying whether standard variance,
the median absolute deviation (robust-mad) or
the more efficient robust variance estimator (robust-Qn)
should be used
Designed for data extracted from time series of satellite imagery. Then, it is expected that
length(x) be a multiple of lenPeriod. When m is provided,
ncol(m) must be equal to lenPeriod. Default of lenPeriod corresponds to the
temporal resolution of some MODIS products.
Method standard invokes sd whereas robust-mad
uses the median absolute deviation of mad and robust-Qn
utilizes the robust scale estimator implemented in Qn.
This function does not allow missing values.